@@ -18,8 +18,8 @@
 
 from gi.repository import Gdk
 from gi.repository import Gtk
-import gobject
-from gettext import gettext as _
+from gi.repository import GObject
+from gnomedvb import _
 import gnomedvb
 from gnomedvb.ui.widgets.ChannelsStore import ChannelsStore
 from gnomedvb.ui.widgets.ChannelsView import ChannelsView
@@ -37,7 +37,7 @@ from gnomedvb.ui.recordings.RecordingsDialog import RecordingsDialog
 class ControlCenterWindow(Gtk.Window):
 
     def __init__(self, model):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
         
         self.runningnextstore = None
         self.scrolledrunningnext = None
@@ -74,7 +74,7 @@ class ControlCenterWindow(Gtk.Window):
         self.vbox_left = Gtk.VBox(spacing=6)
         self.hpaned.pack1(self.vbox_left)
 
-        self.devgroupslist = Gtk.ListStore(str, int, gobject.GObject)
+        self.devgroupslist = Gtk.ListStore(str, int, GObject.GObject)
         self.devgroupslist.connect("row-inserted", self._on_devgroupslist_inserted)
         
         self.devgroupscombo = Gtk.ComboBox.new_with_model_and_entry(self.devgroupslist)
@@ -375,7 +375,7 @@ class ControlCenterWindow(Gtk.Window):
 
     def _on_manager_group_added(self, manager, group_id):
         group = self.manager.get_device_group(group_id)
-        if group:
+        if group != None:
             self._append_group(group)
             self.check_single_group_mode()
         
@@ -417,7 +417,7 @@ class ControlCenterWindow(Gtk.Window):
     def _on_devgroupslist_inserted(self, model, path, aiter):
         if len(model) == 1:
             # Delay the call otherwise we get DBus errors
-            gobject.timeout_add(100, self._select_first_group)
+            GObject.timeout_add(100, self._select_first_group)
     
     def _on_channel_selected(self, treeselection):
         model, aiter = treeselection.get_selected()
@@ -506,7 +506,7 @@ class ControlCenterWindow(Gtk.Window):
                     type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
                 dialog.set_markup (
                     "<big><span weight=\"bold\">%s</span></big>" % _("Schedule recording for the selected event?"))
-                rec_id = -1
+
                 success = True
                 if dialog.run() == Gtk.ResponseType.YES:
                     event_id = model[aiter][model.COL_EVENT_ID]
