@@ -16,14 +16,14 @@
 # You should have received a copy of the GNU General Public License
 # along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 
-import gobject
+from gi.repository import GObject
 from gi.repository import Gtk
 import subprocess
 from gnomedvb import global_error_handler
 from gnomedvb.ui.preferences.Dialogs import *
 from gnomedvb.ui.preferences.DeviceGroupsView import *
 from gnomedvb.ui.widgets.Frame import Frame
-from gettext import gettext as _
+from gnomedvb import _
 from gnomedvb.Device import Device
 
 class Preferences(Gtk.Window):
@@ -34,7 +34,7 @@ class Preferences(Gtk.Window):
      BUTTON_PREFERENCES,) = range(4)
 
     def __init__(self, model, parent=None):
-        gobject.GObject.__init__(self)
+        GObject.GObject.__init__(self)
 
         self.set_title(_('Digital TV Preferences'))
         if parent:
@@ -43,6 +43,7 @@ class Preferences(Gtk.Window):
         self.set_modal(True)
         self.set_destroy_with_parent(True)
         self.set_default_size(600, 450)
+        self.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
         
         self.vbox = Gtk.VBox()
         self.add(self.vbox)
@@ -242,9 +243,8 @@ class Preferences(Gtk.Window):
                         error_handler=global_error_handler)
                         
     def _on_button_setup_clicked(self, button):
-        pass        
+        subprocess.Popen(["gnome-dvb-setup"])
         # XXX XID
-        #subprocess.Popen(["gnome-dvb-setup",
         #    "--transient-for=%d" % self.get_window().xid])
 
     def _on_button_new_clicked(self, button):
@@ -324,7 +324,7 @@ class Preferences(Gtk.Window):
 
     def _on_manager_group_added(self, manager, group_id):
         group = manager.get_device_group(group_id)
-        if group:
+        if group != None:
             self._append_group(group, remove_unassigned=True)
     
     def _on_manager_group_removed(self, manager, group_id):        
