@@ -18,7 +18,7 @@
 
 import datetime
 from gi.repository import Gtk
-from gettext import gettext as _
+from gnomedvb import _
 from gnomedvb.ui.widgets.ChannelsStore import ChannelsStore
 from gnomedvb.ui.widgets.ChannelsView import ChannelsView
 from gnomedvb.ui.widgets.Frame import TextFieldLabel
